@@ -6,7 +6,7 @@ import os, sys, ast, json, glob, platform, subprocess, random, requests, socket,
 
 # inc imports.
 import syst3m
-from fil3s import *
+from dev0s import *
 
 # source.
 ALIAS = "netw0rk"
